@@ -8,25 +8,24 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-1998 by Bradford W. Mott
+// Copyright (c) 1995-2005 by Bradford W. Mott and the Stella team
 //
 // See the file "license" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //
-// $Id: Event.cxx,v 1.1.1.1 2001/12/27 19:54:21 bwmott Exp $
+// $Id: Event.cxx,v 1.7 2005/12/28 22:56:36 stephena Exp $
 //============================================================================
 
 #include "Event.hxx"
+#include "EventStreamer.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Event::Event()
-    : myNumberOfTypes(Event::LastType)
+Event::Event(EventStreamer* ev)
+  : myNumberOfTypes(Event::LastType),
+    myEventStreamer(ev)
 {
   // Set all of the events to 0 / false to start with
-  for(int i = 0; i < myNumberOfTypes; ++i)
-  {
-    myValues[i] = 0;
-  }
+  clear();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -44,5 +43,15 @@ Int32 Event::get(Type type) const
 void Event::set(Type type, Int32 value)
 {
   myValues[type] = value;
+
+  // Add to history if we're in recording mode
+  if(myEventStreamer->isRecording())
+    myEventStreamer->addEvent(type, value);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void Event::clear()
+{
+  for(int i = 0; i < myNumberOfTypes; ++i)
+    myValues[i] = 0;
+}
